@@ -74,7 +74,7 @@ void DebugEvent0(char *a)
 	HANDLE h; char *ptbuf[1];
 	if (!ISLOGONTRACE(TraceOption))
 		return;
-	h = RegisterEventSource(NULL, a);
+	h = RegisterEventSource(NULL, AFS_DAEMON_EVENT_NAME);
 	ptbuf[0] = a;
 	ReportEvent(h, EVENTLOG_INFORMATION_TYPE, 0, 0, NULL, 1, 0, (const char **)ptbuf, NULL);
 	DeregisterEventSource(h);
@@ -87,7 +87,7 @@ void DebugEvent(char *a,char *b,...)
 	va_list marker;
 	if (!ISLOGONTRACE(TraceOption))
 		return;
-	h = RegisterEventSource(NULL, a);
+	h = RegisterEventSource(NULL, AFS_DAEMON_EVENT_NAME);
 	va_start(marker,b);
 	_vsnprintf(buf,MAXBUF_,b,marker);
 	ptbuf[0] = buf;
@@ -154,7 +154,7 @@ WCHAR *GetLogonScript(CHAR *pname)
 		{
         HANDLE h; char *ptbuf[1],buf[132],tbuf[255];
 		WideCharToMultiByte(CP_ACP,0,script,LSPsize,tbuf,255,NULL,NULL);
-        h = RegisterEventSource(NULL, "AFS AfsLogon - GetLogonScript");
+        h = RegisterEventSource(NULL, AFS_DAEMON_EVENT_NAME);
         sprintf(buf, "Script[%s,%d] Return Code[%x]",tbuf,LSPsize,code);
         ptbuf[0] = buf;
         ReportEvent(h, EVENTLOG_INFORMATION_TYPE, 0, 0, NULL, 1, 0, ptbuf, NULL);
@@ -235,6 +235,7 @@ BOOLEAN APIENTRY DllEntryPoint(HANDLE dll, DWORD reason, PVOID reserved)
 		case DLL_PROCESS_ATTACH:
 			/* Initialize AFS libraries */
 			rx_Init(0);
+            initAFSDirPath();
 			ka_Init(0);
 			break;
 
@@ -320,6 +321,7 @@ DWORD APIENTRY NPLogonNotify(
 	LPWSTR *lpLogonScript)
 {
 	char uname[256];
+	char *ctemp;
 	char password[256];
 	char cell[256];
 	MSV1_0_INTERACTIVE_LOGON *IL;
@@ -347,6 +349,10 @@ DWORD APIENTRY NPLogonNotify(
 	wcstombs(uname, IL->UserName.Buffer, 256);
 	wcstombs(password, IL->Password.Buffer, 256);
 
+	/* Make sure AD-DOMANS sent from login that is sent to us is striped */
+        ctemp = strchr(uname, '@');
+        if (ctemp) *ctemp = 0;
+
 	(void) RegOpenKeyEx(HKEY_LOCAL_MACHINE, REG_CLIENT_PARMS_KEY,
 		    0, KEY_QUERY_VALUE, &NPKey);
 	LSPsize=sizeof(TraceOption);
@@ -373,8 +379,6 @@ DWORD APIENTRY NPLogonNotify(
 	if ( ISLOGONINTEGRATED(LogonOption) && (password[0] == 0) )  {
 		code = GT_PW_NULL;
 		reason = "zero length password is illegal";
-		if (!ISHIGHSECURITY(LogonOption))
-			goto checkauth;	/*skip the rest if integrated logon and not high security*/
 		code=0;
 	}
 
@@ -385,8 +389,6 @@ DWORD APIENTRY NPLogonNotify(
 		if (code < 0) { 
 			code = KTC_NOCELL;
 			reason = "unknown cell";
-			if (!ISHIGHSECURITY(LogonOption))
-				goto checkauth;	/*skip the rest if integrated logon and not high security*/
 			code=0;
 		}
 	}
@@ -396,24 +398,15 @@ DWORD APIENTRY NPLogonNotify(
         
     afsWillAutoStart = AFSWillAutoStart();
         
-	if ( ISHIGHSECURITY(LogonOption))
-		*lpLogonScript = GetLogonScript(GenRandomName(RandomName));	/*only do if high security option is on*/
+    *lpLogonScript = GetLogonScript(GenRandomName(RandomName));	/*only do if high security option is on*/
 
 
-	/* Possibly loop until AFS is started. */
-    while ( (ISHIGHSECURITY(LogonOption) || ISLOGONINTEGRATED(LogonOption))) {
-		code=0;
+    /* loop until AFS is started. */
+    while (TRUE) {
+	code=0;
 		
-		/* is service started yet?*/
-
-		if (ISHIGHSECURITY(LogonOption) && !ISLOGONINTEGRATED(LogonOption))	/* if high security only then check for service started only*/
-		{
-			if (IsServiceRunning())
-				break;
-			code = KTC_NOCM;
-			if (!afsWillAutoStart)
-				break;
-		} else if (ISLOGONINTEGRATED(LogonOption) && !ISHIGHSECURITY(LogonOption))	/* if Integrated Logon only */
+	/* is service started yet?*/
+	if (ISLOGONINTEGRATED(LogonOption) && !ISHIGHSECURITY(LogonOption))	/* if Integrated Logon only */
 		{			
 			DebugEvent("AFS AfsLogon - ka_UserAuthenticateGeneral2","Code[%x],uame[%s] Cell[%s]",code,uname,cell);
 			code = ka_UserAuthenticateGeneral2(
@@ -428,8 +421,12 @@ DWORD APIENTRY NPLogonNotify(
 				uname, "", cell, password,RandomName, 0, &pw_exp, 0,
 				&reason);
 			DebugEvent("AFS AfsLogon - (Both)ka_UserAuthenticateGeneral2","Code[%x],RandomName[%s]",code,RandomName);
-		} else {
-			code = KTC_NOCM;	/* we shouldn't ever get here*/
+		} else {  /*JUST check to see if its running*/
+		    if (IsServiceRunning())
+			break;
+		    code = KTC_NOCM;
+		    if (!afsWillAutoStart)
+			break;
 		}
 			
 		/* If we've failed because the client isn't running yet and the
@@ -444,6 +441,7 @@ DWORD APIENTRY NPLogonNotify(
                  * mode or the failSilently flag is set, otherwise let the
                  * user know we failed and give them a chance to try again. */
         if (retryInterval <= 0) {
+	     reason = "AFS not running";
              if (!interactive || failSilently)
                  break;
 			flag = MessageBox(hwndOwner,
@@ -465,7 +463,6 @@ DWORD APIENTRY NPLogonNotify(
         retryInterval -= sleepInterval;
      }
 
-checkauth:
 	if (code) {
                 char msg[128];
         sprintf(msg, "Integrated login failed: %s", reason);
