@@ -22,7 +22,7 @@
 
 #include "afsd.h"
 
-void afsi_log();
+extern void afsi_log(char *pattern, ...);
 
 /* This module implements the buffer package used by the local transaction
  * system (cm).  It is initialized by calling cm_Init, which calls buf_Init;
@@ -401,6 +401,9 @@ long buf_AddBuffers(long nbuffers)
 	HANDLE hm;
 	long cs;
 
+    afsi_log("%d buffers being added to the existing cache of size %d",
+              nbuffers, buf_nbuffers);
+
 	/*
 	 * Cache file mapping constrained by
 	 * system allocation granularity;
@@ -1441,5 +1444,6 @@ int cm_DumpBufHashTable(FILE *outputFile, char *cookie)
     WriteFile(outputFile, output, strlen(output), &zilch, NULL);
 
     lock_ReleaseRead(&buf_globalLock);
+    return 0;
 }
 
