@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/budb/server.c,v 1.11 2003/07/15 23:14:48 shadow Exp $");
+    ("$Header: /cvs/openafs/src/budb/server.c,v 1.13 2003/12/08 01:45:28 jaltman Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -58,10 +58,6 @@ RCSID
 #include "globals.h"
 #include "afs/audit.h"
 
-
-extern afs_int32 ubik_lastYesTime;
-extern afs_int32 ubik_nBuffers;
-
 struct ubik_dbase *BU_dbase;
 struct afsconf_dir *BU_conf;	/* for getting cell info */
 
@@ -554,6 +550,7 @@ LogDebug(level, a, b, c, d, e, f, g, h, i)
 	    fclose(globalConfPtr->log);
 	}
     }
+    return 0;
 }
 
 static char *
@@ -582,6 +579,7 @@ Log(a, b, c, d, e, f, g, h, i)
 	fflush(globalConfPtr->log);
 	fclose(globalConfPtr->log);
     }
+    return 0;
 }
 
  /*VARARGS*/
@@ -604,6 +602,7 @@ LogError(code, a, b, c, d, e, f, g, h, i)
 	fflush(globalConfPtr->log);
 	fclose(globalConfPtr->log);
     }
+    return 0;
 }
 
 
@@ -626,4 +625,5 @@ LogNetDump(dumpPtr)
 	printDump(globalConfPtr->log, &hostDump);
 	fclose(globalConfPtr->log);
     }
+    return 0;
 }
